swyft API
=====================

Posterior inference
-------------------

.. automodule:: swyft.inference
  :members:
  :inherited-members:
  :special-members: __len__, __getitem__

Data store
----------

.. automodule:: swyft.store
  :members:
  :inherited-members:
  :special-members: __len__, __getitem__

Networks definitions
--------------------

.. automodule:: swyft.networks
  :members:
  :special-members: __len__, __getitem__

Bounds for prior truncation
---------------------------

.. automodule:: swyft.bounds
  :members:
  :inherited-members:
  :special-members: __len__, __getitem__

Utility functions
-----------------

.. automodule:: swyft.utils
  :members:
  :inherited-members:
  :special-members: __len__, __getitem__

